@@ -168,7 +168,7 @@ bool KateGlobalConfig::setFallbackEncoding(const QString &encoding)
 
 KateDocumentConfig::KateDocumentConfig()
     : m_indentationWidth(2),
-      m_tabWidth(8),
+      m_tabWidth(4),
       m_tabHandling(tabSmart),
       m_configFlags(0),
       m_wordWrapAt(80),
@@ -212,7 +212,7 @@ KateDocumentConfig::KateDocumentConfig()
 
 KateDocumentConfig::KateDocumentConfig(const KConfigGroup &cg)
     : m_indentationWidth(2),
-      m_tabWidth(8),
+      m_tabWidth(4),
       m_tabHandling(tabSmart),
       m_configFlags(0),
       m_wordWrapAt(80),
@@ -309,7 +309,7 @@ const char KEY_BACKSPACE_INDENTS[] = "Indent On Backspace";
 const char KEY_SHOW_SPACES[] = "Show Spaces";
 const char KEY_REPLACE_TABS_DYN[] = "ReplaceTabsDyn";
 const char KEY_REMOVE_SPACES[] = "Remove Spaces";
-const char KEY_NEWLINE_AT_EOF[] = "Newline At EOF";
+const char KEY_NEWLINE_AT_EOF[] = "Newline at End of File";
 const char KEY_OVR[] = "Overwrite Mode";
 const char KEY_ENCODING[] = "Encoding";
 const char KEY_EOL[] = "End of Line";
@@ -329,7 +329,7 @@ void KateDocumentConfig::readConfig(const KConfigGroup &config)
 {
     configStart();
 
-    setTabWidth(config.readEntry(KEY_TAB_WIDTH, 8));
+    setTabWidth(config.readEntry(KEY_TAB_WIDTH, 4));
 
     setIndentationWidth(config.readEntry(KEY_INDENTATION_WIDTH, 4));
 
@@ -350,7 +350,7 @@ void KateDocumentConfig::readConfig(const KConfigGroup &config)
     setShowSpaces(config.readEntry(KEY_SHOW_SPACES, false));
     setReplaceTabsDyn(config.readEntry(KEY_REPLACE_TABS_DYN, true));
     setRemoveSpaces(config.readEntry(KEY_REMOVE_SPACES, 0));
-    setNewLineAtEof(config.readEntry(KEY_NEWLINE_AT_EOF, false));
+    setNewLineAtEof(config.readEntry(KEY_NEWLINE_AT_EOF, true));
     setOvr(config.readEntry(KEY_OVR, false));
 
     setEncoding(config.readEntry(KEY_ENCODING, ""));
@@ -364,7 +364,7 @@ void KateDocumentConfig::readConfig(const KConfigGroup &config)
 
     setBackupPrefix(config.readEntry(KEY_BACKUP_PREFIX, QString()));
 
-    setBackupSuffix(config.readEntry(KEY_BACKUP_SUFFIX, QString::fromLatin1("~")));
+    setBackupSuffix(config.readEntry(KEY_BACKUP_SUFFIX, QStringLiteral("~")));
 
     setSwapFileMode(config.readEntry(KEY_SWAP_FILE_MODE, (uint)EnableSwapFile));
     setSwapDirectory(config.readEntry(KEY_SWAP_DIRECTORY, QString()));
@@ -880,7 +880,10 @@ QTextCodec *KateDocumentConfig::codec() const
 {
     if (m_encodingSet || isGlobal()) {
         if (m_encoding.isEmpty() && isGlobal()) {
-            return QTextCodec::codecForLocale();
+            // default to UTF-8, this makes sense to have a usable encoding detection
+            // else for people that have by bad luck some encoding like latin1 as default, no encoding detection will work
+            // see e.g. bug 362604 for windows
+            return QTextCodec::codecForName("UTF-8");
         } else if (m_encoding.isEmpty()) {
             return s_global->codec();
         } else {
@@ -930,14 +933,14 @@ int KateDocumentConfig::eol() const
 QString KateDocumentConfig::eolString()
 {
     if (eol() == KateDocumentConfig::eolUnix) {
-        return QString(QLatin1String("\n"));
+        return QStringLiteral("\n");
     } else if (eol() == KateDocumentConfig::eolDos) {
-        return QString(QLatin1String("\r\n"));
+        return QStringLiteral("\r\n");
     } else if (eol() == KateDocumentConfig::eolMac) {
-        return QString(QLatin1String("\r"));
+        return QStringLiteral("\r");
     }
 
-    return QString(QLatin1String("\n"));
+    return QStringLiteral("\n");
 }
 
 void KateDocumentConfig::setEol(int mode)
@@ -2360,7 +2363,7 @@ void KateRendererConfig::setSchemaInternal(const QString &schema)
     m_foldingColorSet = true;
     m_lineNumberColor = config.readEntry("Color Line Number", colors.color(Kate::LineNumber));
     m_lineNumberColorSet = true;
-    m_currentLineNumberColor = config.readEntry("Current Color Line Number", colors.color(Kate::CurrentLineNumber));
+    m_currentLineNumberColor = config.readEntry("Color Current Line Number", colors.color(Kate::CurrentLineNumber));
     m_currentLineNumberColorSet = true;
     m_separatorColor = config.readEntry("Color Separator", colors.color(Kate::Separator));
     m_separatorColorSet = true;
@@ -2377,7 +2380,7 @@ void KateRendererConfig::setSchemaInternal(const QString &schema)
     m_replaceHighlightColorSet = true;
 
     for (int i = Kate::FIRST_MARK; i <= Kate::LAST_MARK; i++) {
-        QColor col = config.readEntry(QString::fromLatin1("Color MarkType %1").arg(i + 1), colors.mark(i));
+        QColor col = config.readEntry(QStringLiteral("Color MarkType %1").arg(i + 1), colors.mark(i));
         m_lineMarkerColorSet[i] = true;
         m_lineMarkerColor[i] = col;
     }
@@ -2388,15 +2391,15 @@ void KateRendererConfig::setSchemaInternal(const QString &schema)
     m_fontMetrics = QFontMetricsF(m_font);
     m_fontSet = true;
 
-    m_templateBackgroundColor = config.readEntry(QLatin1String("Color Template Background"), colors.color(Kate::TemplateBackground));
+    m_templateBackgroundColor = config.readEntry(QStringLiteral("Color Template Background"), colors.color(Kate::TemplateBackground));
 
-    m_templateFocusedEditablePlaceholderColor = config.readEntry(QLatin1String("Color Template Focused Editable Placeholder"),
+    m_templateFocusedEditablePlaceholderColor = config.readEntry(QStringLiteral("Color Template Focused Editable Placeholder"),
                                                                  colors.color(Kate::TemplateFocusedEditablePlaceholder));
 
-    m_templateEditablePlaceholderColor = config.readEntry(QLatin1String("Color Template Editable Placeholder"),
+    m_templateEditablePlaceholderColor = config.readEntry(QStringLiteral("Color Template Editable Placeholder"),
                                                           colors.color(Kate::TemplateEditablePlaceholder));
 
-    m_templateNotEditablePlaceholderColor = config.readEntry(QLatin1String("Color Template Not Editable Placeholder"),
+    m_templateNotEditablePlaceholderColor = config.readEntry(QStringLiteral("Color Template Not Editable Placeholder"),
                                                              colors.color(Kate::TemplateNotEditablePlaceholder));
 
     m_templateColorsSet = true;
